@@ -1,7 +1,13 @@
 import pytest
 
-from plangym.api_tests import batch_size, display, generate_test_cases, TestPlanEnv  # noqa: F401
-from plangym.vectorization import ParallelEnvironment
+from plangym.api_tests import (  # noqa: F401
+    batch_size,
+    display,
+    generate_test_cases,
+    TestPlanEnv,
+    TestPlangymEnv,
+    TestVideogameEnv,
+)
 from plangym.videogames.nes import MarioEnv
 
 
@@ -12,6 +18,4 @@ env_names = ["SuperMarioBros-v0", "SuperMarioBros-v1", "SuperMarioBros2-v0"]
     params=generate_test_cases(env_names, MarioEnv, n_workers_values=[None, 2]), scope="module"
 )
 def env(request):
-    env = request.param()
-    yield env
-    env.close()
+    return request.param()
